using System;
using System.Xml;

namespace MediaCenter.DigitalHome.parser
{
	/// <summary>
	/// Parser for fileTransfer messages.
	/// </summary>
	public class FileDownloadParser : XMLServiceParser
	{
		private FileTransferManager ftMan;
		
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="client">The client tis parser belongs to</param>
		public FileDownloadParser(DigitalHomeClient client)  : base(XMLVariables.FILE_DOWNLOAD_ID, client)
		{
			ftMan = client.getFileTransferManager();
		}
		
		/// <summary>
		/// Override method.
		/// Parses the message received and calls the appropriate methods on the FileTransferManager
		/// </summary>
		/// <param name="root">The root element of the received message</param>
		public override void receiveXML(XmlElement root) 
		{			
			XmlElement body = (XmlElement)root.FirstChild;
			XmlNodeList statusList = body.GetElementsByTagName(XMLVariables.STATUS);
			XmlNodeList fileTypeList = body.GetElementsByTagName(XMLVariables.FILE_TYPE);
			XmlNodeList fileNameList = body.GetElementsByTagName(XMLVariables.FILE_NAME);

			/* This is a status message */
			if(statusList.Count>0)
			{	
				string status = statusList[0].InnerText;
								
				ftMan.downloadStatusReceived(status);
			}
			/* This is a file receive message */
			else if (fileTypeList.Count > 0 && fileNameList.Count > 0)
			{
				string fileType = fileTypeList[0].InnerText;
				string fileName = fileNameList[0].InnerText;
				
				ftMan.fileDownloadInfoReceived(fileName, fileType);
			}
			/* This is an unknown type of message */
			else 
			{
				client.log("FileTransfer: parser har mottatt feil meldingsformat");
			}	
		}
	}
}
