using System;
using System.Xml;

namespace MediaCenter.DigitalHome.parser
{
	/// <summary>
	/// Parser for FileUpload maeeages.
	/// </summary>
	public class FileUploadParser : XMLServiceParser
	{
		private FileTransferManager ftMan;
		private FileTypeResolver resolver;
		
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="client">The client tis parser belongs to</param>
		public FileUploadParser(DigitalHomeClient client) : base(XMLVariables.FILE_UPLOAD_ID, client)
		{	
			ftMan = client.getFileTransferManager();
			resolver = new FileTypeResolver();
		}
		
		/// <summary>
		/// Override method.
		/// Parses the message received and passes the information on to the FileTransferManager
		/// </summary>
		/// <param name="root">The root element of the received messaget</param>
		public override void receiveXML(XmlElement root) 
		{
			XmlElement body = (XmlElement)root.FirstChild;
			XmlNodeList statusList = body.GetElementsByTagName(XMLVariables.STATUS);
			XmlNodeList fileTypeList = body.GetElementsByTagName(XMLVariables.FILE_TYPE);
			XmlNodeList fileNameList = body.GetElementsByTagName(XMLVariables.FILE_NAME);

			/* This is a status message */
			if(statusList.Count>0)
			{	
				string status = statusList[0].InnerText;
				
				client.log("FileUploadParser: mottatt status "+ status);
				
				ftMan.uploadStatusReceived(status);
			}
			/* This is a file upload request */
			else if (fileTypeList.Count > 0 && fileNameList.Count > 0)
			{
				string fileType = fileTypeList[0].InnerText;
				string fileName = fileNameList[0].InnerText;
				string path = Environment.GetFolderPath(Environment.SpecialFolder.Personal);
				
				/* Resolves the path of the requested file */
				if (resolver.isAudio(fileType))
				{
					path = Environment.GetFolderPath(Environment.SpecialFolder.MyMusic);
				}
				else if(resolver.isPicture(fileType))
				{
					path = Environment.GetFolderPath(Environment.SpecialFolder.MyPictures);
				}
				
				client.log("FileUploadParser: mottatt filinfo "+ fileName +"."+ fileType);

				ftMan.fileUploadRequestReceived(path, fileName, fileType);
			}
			/* This is an unknown type of message */
			else 
			{
				client.log("FileUploadParser: feil meldingsformat");
			}	
		}
	}
}
