using System;
using System.Xml;

namespace MediaCenter.DigitalHome.parser
{
	/// <summary>
	/// Parser for MessageToUser messages.
	/// </summary>
	public class MessageToUserParser : XMLServiceParser
	{

		private readonly string TITLE = "title";
		private readonly string MESSAGE = "message";
		
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="client">The client tis parser belongs to</param>
		public MessageToUserParser(DigitalHomeClient client) : base("MessageToUser", client)
		{
		}
		
		/// <summary>
		/// Override method.
		/// Creates a Media Center message box with title and content as
		/// set in the MessageToUser message received.
		/// </summary>
		/// <param name="root">The root element of the received message</param>
		public override void receiveXML(XmlElement root) 
		{
			XmlElement body = (XmlElement)root.FirstChild;
			XmlNodeList titleList = body.GetElementsByTagName(TITLE);
			string title = titleList[0].InnerText;
			XmlNodeList messageList = body.GetElementsByTagName(MESSAGE);
			string message = messageList[0].InnerText;

			client.displayPopUp(title, message);
		}
	}
}
