using System;
using System.Xml;
using MediaCenter.DigitalHome;

namespace MediaCenter.DigitalHome.parser
{
	/// <summary>
	/// Abstract class.
	/// All XmlParsers should inherit the XMLServiceParser
	/// </summary>
	public abstract class XMLServiceParser
	{
		protected string serviceId;
		protected DigitalHomeClient client;
		
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="serviceId">The service's Id</param>
		/// <param name="client">The client this parser belongs to</param>
		public XMLServiceParser(string serviceId, DigitalHomeClient client)
		{
			this.serviceId = serviceId;
			this.client = client;
		}
		
		/// <summary>
		/// Gets the serviceId
		/// </summary>
		/// <returns>The serviceId</returns>
		public string getServiceID()
		{
			return serviceId;
		}
		
		/// <summary>
		/// Abstract method used to receive XML documents.
		/// All XmlParsers must create an override for this method.
		/// </summary>
		/// <param name="root">The root element of the received message</param>
		public abstract void receiveXML(XmlElement root);
	}
}
