using System;
using System.Net.Sockets;
using System.Net;
using System.IO;
using System.Text;
using System.Threading;
using System.Xml;

namespace MediaCenter.DigitalHome
{
	/// <summary>
	/// Abstract class. All connections to the server should inherit this class
	/// </summary>
	public abstract class Connection
	{
		protected DigitalHomeClient client;
		protected TcpClient socket;
		protected NetworkStream stream;
		protected bool running = true;
		
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="client">The Client holding this Connection</param>
		public Connection(DigitalHomeClient client)
		{
			this.client = client;
		}
		
		/// <summary>
		/// The main thread method
		/// </summary>
		public abstract void run();
		
		/// <summary>
		/// closes this connection
		/// </summary>
		public void close() 
		{
			this.running = false;
		}
		
		/// <summary>
		/// Sets a boolean telling if the connection shal run or not
		/// </summary>
		/// <param name="running"></param>
		public void setRunning(bool running)
		{
			this.running = running;
		}
		
		/// <summary>
		/// Checks if the connection is running
		/// </summary>
		/// <returns>The running status of the connection</returns>
		public bool isRunning()
		{
			return running;
		}
	}
}

