using System;
using System.Xml;
using System.Threading;
using System.Collections;
using MediaCenter.DigitalHome.parser;
using Microsoft.MediaCenter.AddIn;


namespace MediaCenter.DigitalHome
{
	/// <summary>
	/// This is the main class of the add-in. 
	/// </summary>
	public class DigitalHomeClient : MarshalByRefObject, IAddInModule, IAddInEntryPoint
	{
		private static readonly string CLIENT_VERSION = "3.0";
		private string username = "andreas";
		private string password = "";

		private XMLConnection xmlCon;
		private ParseManager parseMan;
		private FileTransferManager ftMan;

		private AddInHost host;

		/// <summary>
		/// Passes an XmlDocument to the parse manager
		/// </summary>
		/// <param name="doc">The XmlDocument to be parsed</param>
		public void receiveXMLDoc(XmlDocument doc)
		{
			parseMan.distributeXMLDoc(doc);	
		}
	
		/// <summary>
		/// Gets the XmlConnection
		/// </summary>
		/// <returns>The XmlConnection</returns>
		public XMLConnection getXmlConnection()
		{
			return xmlCon;
		}
		
		/// <summary>
		/// Gets the client version
		/// </summary>
		/// <returns>the client version</returns>
		public string getClientVersion()
		{
			return CLIENT_VERSION;
		}

		/// <summary>
		/// Gets the DownloadManager
		/// </summary>
		/// <returns>The Download Manager</returns>
		public FileTransferManager getFileTransferManager()
		{
			return ftMan;
		}
		
		/// <summary>
		/// Gets the username
		/// </summary>
		/// <returns>The username</returns>
		public string getUsername()
		{
			return username;
		}

		/// <summary>
		/// Log method reserved for future use.
		/// </summary>
		/// <param name="text">The text to be loged</param>
		public void log(string text)
		{
			//TODO: fikse logging mot en logfil
		}
		
		/// <summary>
		/// Displays a Media Center message box. The messagebox times out after 10 seconds.
		/// </summary>
		/// <param name="title">The title of the message box</param>
		/// <param name="message">The content of the message box</param>
		public void displayPopUp(string title, string message)
		{
			Object[] oButtons = new Object[1];
			oButtons[0] = 1;

			host.HostControl.Dialog(message, title, oButtons, 10, false, null, null);
		}

		/// <summary>
		/// Add-in initialize method
		/// </summary>
		/// <param name="dictAppInfo">AppInfo</param>
		/// <param name="dictEntryPoint">EntryPoint</param>
		void IAddInModule.Initialize(IDictionary dictAppInfo, IDictionary dictEntryPoint)
		{
			// Write any initialization code here
		}
		
		/// <summary>
		/// Add-in uninitialize method. 
		/// </summary>
		void IAddInModule.Uninitialize()
		{
			xmlCon.close();
			ftMan.close();
		}
		
		/// <summary>
		/// Add-in launch method
		/// </summary>
		/// <param name="host"></param>
		void IAddInEntryPoint.Launch(AddInHost host)
		{
			// This is the main part of the application, this method
			// will get called when the addin is started.
			this.host = host;

			xmlCon = new XMLConnection(this);
			ftMan = new FileTransferManager(this, xmlCon);
			parseMan = new ParseManager(this);
			
			Thread t1 = new Thread(new ThreadStart(xmlCon.run));
			t1.IsBackground = true;
			t1.Start();

			/* Send an auth message to the server*/
			xmlCon.sendAuthMessage(username, password);		

			/* Keeps the add-in from terminating. 
			 * Sleeps 5 seconds each run to limit CPU usage
			 * */
			while(true)
			{
				Thread.Sleep(5000);
			}
		}
	}
}