using System;
using System.Collections;

namespace MediaCenter.DigitalHome
{
	/// <summary>
	/// Static class used to extract the path, name and extention of a file from one single string.
	/// </summary>
	public class FileInfoTokenizer
	{
		
		public FileInfoTokenizer()
		{			
		}
		
		/// <summary>
		/// Splits a string into an array containing path, file name and extention
		/// </summary>
		/// <param name="completePath">The complete path of the file (path\filename.extention)</param>
		/// <returns>An array of the form [path, filename, extention]</returns>
		public static string[] tokenize(string completePath)
		{
			string[] result = new string[3];
			int pointerExtension = completePath.LastIndexOf(".");
			int pointerPath = completePath.LastIndexOf("\\");
			char[] completePathArray = completePath.ToCharArray();
			char[] pathArray = new char[pointerPath + 1];
			char[] extensionArray = new char[completePathArray.Length - pointerExtension - 1];
			char[] nameArray = new char[completePathArray.Length - pathArray.Length - extensionArray.Length - 1];
		
			for (int i = 0; i < completePathArray.Length; i++) 
			{
				if (i < pathArray.Length) 
				{
					pathArray[i] = completePathArray[i];
				} 
				else if (i < pointerExtension) 
				{
					nameArray[i - pathArray.Length] = completePathArray[i];
				} 
				else if (i == pointerExtension)
				{
					continue;
				} 
				else 
				{
					extensionArray[i - pointerExtension - 1] = completePathArray[i];
				}
			}
			
			result[0] = new String(pathArray);
			result[1] = new String(nameArray);
			result[2] = new String(extensionArray);

			return result;
		}
	}
}
