using System;
using System.Xml;
using System.IO;

namespace MediaCenter.DigitalHome.parser
{
	/// <summary>
	/// Parser for FileList messages.
	/// </summary>
	public class FileListParser : XMLServiceParser
	{		
		private FileTypeResolver resolver;
		
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="client">The client tis parser belongs to</param>
		public FileListParser(DigitalHomeClient client) : base("FileList", client)
		{
			resolver = new FileTypeResolver();
		}
		
		/// <summary>
		/// Override method.
		/// Resolves the type and folder of files to be listed
		/// </summary>
		/// <param name="root">The root element of the received message</param>
		public override void receiveXML(XmlElement root) 
		{	
			string type;
			string path;
			string[] files;

			XmlDocument doc;
			XmlDeclaration xmlDecl;
			XmlElement returnRoot;
			XmlElement returnbody;
			XmlElement fileList;

			/* Gets the fileType element */
			XmlElement body = (XmlElement)root.FirstChild;
			XmlNodeList typeList = body.GetElementsByTagName("fileType");
			
			if(typeList.Count <= 0)
			{
				client.log("FileListParser: feil meldingsformat");
				return;
			}
			
			type = typeList[0].InnerText;
			
			/* Files to bie listed: Audio */
			if("audio".Equals(type))
			{
				path = Environment.GetFolderPath(Environment.SpecialFolder.MyMusic);
			} 
			/* Files to bie listed: Pictures */
			else if ("picture".Equals(type))
			{
				path = Environment.GetFolderPath(Environment.SpecialFolder.MyPictures);
			}
			/* Files to bie listed: other */
			else 
			{
				path = Environment.GetFolderPath(Environment.SpecialFolder.Personal);
			}
			
			/* Gets a list of all files in the wanted path */
			files = Directory.GetFiles(path, "*.*");

			/* Creating a file list message to be sent to the server */
			doc = new XmlDocument();
			xmlDecl = doc.CreateXmlDeclaration("1.0", "UTF-8", null);
			returnRoot = doc.CreateElement(XMLVariables.SERVICE_ROOT);
			returnRoot.SetAttribute(XMLVariables.SERVICE_ID, "FileList");
			returnbody = doc.CreateElement(XMLVariables.SERVICE_BODY);
			fileList = doc.CreateElement("fileList");
						
			/* Checks the list of files and adds files of correct type to the file list message */
			if("audio".Equals(type))
			{
				foreach (string f in files) 
				{
					string[] split = FileInfoTokenizer.tokenize(f);
					
					if (resolver.isAudio(split[2])) 
					{
						XmlElement file = doc.CreateElement("file");
						XmlElement fileType = doc.CreateElement(XMLVariables.FILE_TYPE);
						XmlElement fileName = doc.CreateElement(XMLVariables.FILE_NAME);
						XmlText fileTypeText = doc.CreateTextNode(split[2]);
						XmlText fileNameText = doc.CreateTextNode(split[1]);
						
						fileType.AppendChild(fileTypeText);
						fileName.AppendChild(fileNameText);
						file.AppendChild(fileType);
						file.AppendChild(fileName);
						fileList.AppendChild(file);
					}
				}
			} 
			else if ("picture".Equals(type))
			{
				foreach (string f in files) 
				{
					string[] split = FileInfoTokenizer.tokenize(f);
					
					if (resolver.isPicture(split[2])) 
					{
						XmlElement file = doc.CreateElement("file");
						XmlElement fileType = doc.CreateElement(XMLVariables.FILE_TYPE);
						XmlElement fileName = doc.CreateElement(XMLVariables.FILE_NAME);
						XmlText fileTypeText = doc.CreateTextNode(split[2]);
						XmlText fileNameText = doc.CreateTextNode(split[1]);
						
						fileType.AppendChild(fileTypeText);
						fileName.AppendChild(fileNameText);
						file.AppendChild(fileType);
						file.AppendChild(fileName);
						fileList.AppendChild(file);
					}
				}
			}
			else 
			{
				foreach (string f in files) 
				{
					string[] split = FileInfoTokenizer.tokenize(f);

					XmlElement file = doc.CreateElement("file");
					XmlElement fileType = doc.CreateElement(XMLVariables.FILE_TYPE);
					XmlElement fileName = doc.CreateElement(XMLVariables.FILE_NAME);
					XmlText fileTypeText = doc.CreateTextNode(split[2]);
					XmlText fileNameText = doc.CreateTextNode(split[1]);
					
					fileType.AppendChild(fileTypeText);
					fileName.AppendChild(fileNameText);
					file.AppendChild(fileType);
					file.AppendChild(fileName);
					fileList.AppendChild(file);
				}
			}

			/* Finalizes the file list message */
			returnbody.AppendChild(fileList);
			returnRoot.AppendChild(returnbody);
			doc.AppendChild(xmlDecl);
			doc.AppendChild(returnRoot);

			client.log("FileListParser: bygget filliste: "+ doc.OuterXml);

			/* Sends the file list to the server */
			client.getXmlConnection().sendXMLDoc(doc);
		}
	}
}
