using System;
using System.Xml;

namespace MediaCenter.DigitalHome.parser
{
	/// <summary>
	/// Parser for fileTransfer messages.
	/// </summary>
	public class FileTransferParser : XMLServiceParser
	{
		private FileTransferManager ftMan;
		
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="client">The client tis parser belongs to</param>
		public FileTransferParser(DigitalHomeClient client)  : base(XMLVariables.FILE_TRANSFER_ID, client)
		{
			ftMan = client.getFileTransferManager();
		}
		
		/// <summary>
		/// Override method.
		/// Receives an XmlElement, parses it and performs the appropriate actions
		/// </summary>
		/// <param name="root">The root element</param>
		public override void receiveXML(XmlElement root) 
		{			
			XmlElement body = (XmlElement)root.FirstChild;
			XmlNodeList statusList = body.GetElementsByTagName(XMLVariables.STATUS);
			XmlNodeList fileTypeList = body.GetElementsByTagName(XMLVariables.FILE_TYPE);
			XmlNodeList fileNameList = body.GetElementsByTagName(XMLVariables.FILE_NAME);

			/* This is a status message */
			if(statusList.Count>0)
			{	
				client.log("Filetransfer: Statusmelding mottatt");
				string status = statusList[0].InnerText;
				
				client.log("Filtransfer: mottatt status "+ status);
				
				ftMan.statusReceived(status);
			}
				/* This is a file receive message */
			else if (fileTypeList.Count > 0 && fileNameList.Count > 0)
			{
				client.log("FileTransfer: Filinfo mottatt");
				string fileType = fileTypeList[0].InnerText;
				string fileName = fileNameList[0].InnerText;
				
				client.log("Filtransfer: mottatt filinfo "+ fileName +"."+ fileType);

				ftMan.fileInfoReceived(fileName, fileType);
			}
				/* This is an unknown type of message */
			else 
			{
				client.log("FileTransfer: parser har mottatt feil meldingsformat");
			}	
		}
	}
}
