using System;
using System.Collections;

namespace MediaCenter.DigitalHome
{
	/// <summary>
	/// The FileTypeResolver is used to resolve if a file type
	/// is audio, picture or video
	/// </summary>
	public class FileTypeResolver
	{
		private Hashtable audio;
		private Hashtable picture;
		private Hashtable video;
		
		/// <summary>
		/// Constructor initiating the audio, picture and video hashtables
		/// and fills them with data.
		/// </summary>
		public FileTypeResolver()
		{
			audio = new Hashtable();
			picture = new Hashtable();
			video = new Hashtable();
						
			fillAudio();
			fillPicture();
			fillVideo();			
		}

		/// <summary>
		/// Fills the audio hashtable with data
		/// </summary>
		private void fillAudio()
		{
			audio.Add("mp3", null);
			audio.Add("wma", null);
		}
		
		/// <summary>
		/// Fills the picture hashtable with data
		/// </summary>
		private void fillPicture()
		{
			picture.Add("bmp", null);
			picture.Add("gif", null);
			picture.Add("jpg", null);
			picture.Add("jpeg", null);
		}

		/// <summary>
		/// Fills the video hashtable with data
		/// </summary>
		private void fillVideo()
		{
			video.Add("avi", null);
			video.Add("mpeg", null);
			video.Add("mpg", null);
		}
		
		/// <summary>
		/// Method to determin if a file is an audio file,
		/// based on its file type (extention)
		/// </summary>
		/// <param name="fileType">The extention of the file</param>
		/// <returns>True if this is an audio file</returns>
		public bool isAudio(string fileType)
		{
			if(audio.ContainsKey(fileType))
			{
				return true;
			} 
			else
			{
				return false;
			}
		}
		
		/// <summary>
		/// Method to determin if a file is a picture file,
		/// based on its file type (extention)
		/// </summary>
		/// <param name="fileType">The extention of the file</param>
		/// <returns>True if this is a picture file</returns>
		public bool isPicture(string fileType)
		{
			if(picture.ContainsKey(fileType))
			{
				return true;
			} 
			else
			{
				return false;
			}
		}
		
		/// <summary>
		/// Method to determin if a file is a video file,
		/// based on its file type (extention)
		/// </summary>
		/// <param name="fileType">The extention of the file</param>
		/// <returns>True if this is a video file</returns>
		public bool isVideo(string fileType)
		{
			if(video.ContainsKey(fileType))
			{
				return true;
			} 
			else
			{
				return false;
			}
		}
	}
}
