using System;
using System.Xml;
using System.Collections;

namespace MediaCenter.DigitalHome.parser
{
	/// <summary>
	/// A manager for all parsers.
	/// </summary>
	public class ParseManager
	{
		private DigitalHomeClient client;
		private Hashtable parserList;

		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="client">The client that holds this ParseManager</param>
		public ParseManager(DigitalHomeClient client)
		{
			this.client = client;
			parserList = new Hashtable();

			/* To add a parser follw this example:
			 * 
			 * XMLServiceParser service1 = new XMLServiceParser(client);
			 * parserList.Add(service1.getServiceID(), service1);
			 *  */

			XMLServiceParser sysRes = new ServerSystemResponseParser(client);
			parserList.Add(sysRes.getServiceID(), sysRes);

			XMLServiceParser fileDownload = new FileDownloadParser(client);
			parserList.Add(fileDownload.getServiceID(), fileDownload);

			XMLServiceParser fileUpload = new FileUploadParser(client);
			parserList.Add(fileUpload.getServiceID(), fileUpload);

			XMLServiceParser fileList = new FileListParser(client);
			parserList.Add(fileList.getServiceID(), fileList);

			XMLServiceParser tvParser = new ScheduleTvRecordingParser(client);
			parserList.Add(tvParser.getServiceID(), tvParser);
		}
		
		/// <summary>
		/// Resolves the correct parser for the received XmlDocument.
		/// The root element is passed on to the correct parser.
		/// </summary>
		/// <param name="doc">The XmlDocument to be parsed</param>
		public void distributeXMLDoc(XmlDocument doc)
		{			
			XMLServiceParser parser;
			XmlElement root = (XmlElement)doc.LastChild;

			/* Checks if it is a ServerSystemResponse message */
			if (XMLVariables.SERVER_SYSTEM_RESPONSE.Equals(root.Name))
			{
				parser = (XMLServiceParser)parserList[XMLVariables.SERVER_SYSTEM_RESPONSE];
			}
				/* Checks if it is a service message */
			else if (client.getXmlConnection().isAuthed())
			{
				if(XMLVariables.SERVICE_ROOT.Equals(root.Name)) 
				{
					string serviceId = root.GetAttribute(XMLVariables.SERVICE_ID);

					parser = (XMLServiceParser)parserList[serviceId];

					if (parser == null) 
					{
						client.log("ParseManager: Fant ikke parser");
						return;
					}
				}
				else
				{
					return;
				}
			}
			/* The XMLConnection is not authed and the received message is not a ServerSystemresponse */
			else
			{
				return;
			}
			
			/* Sends the root element to the correct parser*/
			parser.receiveXML(root);
		}
	}
}
