using System;
using System.Xml;
using MediaCenter.DigitalHome.service;

namespace MediaCenter.DigitalHome.parser
{
	/// <summary>
	/// Parser for for ScheduleRecording messages.
	/// </summary>
	public class ScheduleTvRecordingParser : XMLServiceParser
	{
		private ScheduleTvRecording scheduler;
		
		/// <summary>
		/// Constructor
		/// </summary>
		/// <param name="client">The client tis parser belongs to</param>
		public ScheduleTvRecordingParser(DigitalHomeClient client) : base(XMLVariables.SCHEDULE_RECORDING_ID ,client)
		{
			scheduler = new ScheduleTvRecording(client);
		}
		
		/// <summary>
		/// Override method.
		/// Extracts the program info and passes it on to the ScheduleTvRecording service.
		/// </summary>
		/// <param name="root">The root element of the received message</param>
		public override void receiveXML(XmlElement root)
		{			
			client.log("scheduleParser: mottatt doc");

			XmlElement body = (XmlElement)root.FirstChild;
			XmlNodeList serviceList = body.GetElementsByTagName(XMLVariables.SCHEDULE_RECORDING_SERVICE);
			XmlNodeList programList = body.GetElementsByTagName(XMLVariables.SCHEDULE_RECORDING_PROGRAM);
			XmlNodeList recurringList = body.GetElementsByTagName(XMLVariables.SCHEDULE_RECORDING_RECURRING);
			
			string service;
			string program;
			string recurring;

			/* Illegal message format */
			if (serviceList.Count == 0 && programList.Count == 0 && recurringList.Count == 0)
			{
				client.log("ScheduleTvRecordingParser: Illegal message format");
				return;
			}

			service = serviceList[0].InnerText;
			program = programList[0].InnerText;
			recurring = recurringList[0].InnerText;
			
			scheduler.addRecording(service, program, recurring);
		}

	}
}
