package digital_home;

/**
 * Class that divides a complete file path into path, filename and extension.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class FileInfoTokenizer {

	private String path;
	private String name;
	private String extension;
	
	/**
	 * Creates a new FileInfoTokenizer tokenizing the given string.
	 * 
	 * @param completePath the string to be tokenized.
	 */
	public FileInfoTokenizer(String completePath) {
		int pointerExtension = completePath.lastIndexOf(".");
		int pointerPath = completePath.lastIndexOf("\\");
		char[] completePathArray = completePath.toCharArray();
		char[] pathArray = new char[pointerPath + 1];
		char[] extensionArray = new char[completePathArray.length - pointerExtension - 1];
		char[] nameArray = new char[completePathArray.length - pathArray.length - extensionArray.length - 1];
		
		for (int i = 0; i < completePathArray.length; i++) {
			if (i < pathArray.length) {
				pathArray[i] = completePathArray[i];
			} else if (i < pointerExtension) {
				nameArray[i - pathArray.length] = completePathArray[i];
			} else if (i == pointerExtension){
				continue;
			} else {
				extensionArray[i - pointerExtension - 1] = completePathArray[i];
			}
		}
		
		path = String.copyValueOf(pathArray);
		name = String.copyValueOf(nameArray);
		extension = String.copyValueOf(extensionArray);
	}
	
	/**
	 * Returns the file extension of the complete path.
	 * 
	 * @return the file extension of the complete path.
	 */
	public String getExtension() {
		return extension;
	}
	
	/**
	 * Returns the filename of the complete path.
	 * 
	 * @return the filename of the complete path.
	 */
	public String getName() {
		return name;
	}

	/**
	 * Returns the path part of the complete path.
	 * 
	 * @return returns the path part of the complete path.
	 */
	public String getPath() {
		return path;
	}
}
