package digital_home.db;

import java.util.ArrayList;

/**
 * Class representing a user from the service provider database.
 * 
 * Note: This class is only a placeholder class for classes containing
 * database connections to the real service provider's database.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class User {

	private String username;
	private ArrayList<Service> services;
	private ArrayList<Service> remoteServices;
	
	/**
	 * Creates a new user with the given username.
	 * 
	 * @param username the username of the user.
	 */
	public User(String username) {
		services = new ArrayList<Service>();
		remoteServices = new ArrayList<Service>();
		this.username = username;
	}
	
	/**
	 * Returns the username of the user.
	 * 
	 * @return the username of the user.
	 */
	public String getUsername() {
		return username;
	}
	
	/**
	 * Returns an ArrayList containing all services this user subscribes to.
	 * 
	 * @return an ArrayList containing all services this user subscribes to.
	 */
	public ArrayList<Service> getServices() {
		return services;
	}
	
	/**
	 * Returns an ArrayList containing all remote services this user subscribes to.
	 * 
	 * @return an ArrayList containing all remote services this user subscribes to.
	 */
	public ArrayList<Service> getRemoteServices() {
		return remoteServices;
	}
	
	/**
	 * Adds a service to this user.
	 * 
	 * @param service the service to be added.
	 */
	public void addService(Service service) {
		services.add(service);
	}
	
	/**
	 * Adds a remote service to this user.
	 * 
	 * @param service the remote service to be added.
	 */
	public void addRemoteService(Service service) {
		remoteServices.add(service);
	}
	
	/**
	 * Checks whether or not the user is subscribing to the given service.
	 * 
	 * @param serviceID the ID of the service.
	 * @return true if the user subscribes to the service, else false.
	 */
	public boolean checkForService(String serviceID) {
		for (Service s: services) {
			if (serviceID.equals(s.getButtonID())) {
				return true;
			}
		}
		return false;
	}
	
	/**
	 * Checks whether or not the user is subscribing to the given remote service.
	 * 
	 * @param serviceID the ID of the service.
	 * @return true if the user subscribes to the remote service, else false.
	 */
	public boolean checkForRemoteService(String serviceID) {
		for (Service s: remoteServices) {
			if (serviceID.equals(s.getButtonID())) {
				return true;
			}
		}
		return false;
	}
	
	public String toString() {
		return username;
	}
	
}
