package digital_home.db;

import java.util.ArrayList;
import java.util.Hashtable;

/**
 * Class representing the service provider database.
 * 
 * Note: This class is only a placeholder class for classes containing
 * database connections to the real service provider's database.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class UserDatabase {
	
	private Hashtable<String, User> database;
	
	/**
	 * Creates a new database with some users each subscribing to some services.
	 */
	public UserDatabase() {
		database = new Hashtable<String, User>();
		
		/* Creates some empty services. */
		Service[] services = new Service[4];
		for (int i = 1; i < 5; i++) {
			services[i-1] = new Service("btnService" + i, "Tjeneste " + i, "service" + i + ".jsp");
		}
		
		/* Creates some real services. */
		Service games = new Service("btnGames", "Spill", "games.jsp");
		Service pic = new Service("btnPictures", "Last ned bilder", "pictureService.jsp");
		
		/* Creates some remote services. */
		Service downloadPictures = new Service("pictureDownload", "Last ned bilder til ditt Media Center", "pictureDownload.jsp");
		Service uploadPictures = new Service("pictureUpload", "Hent bilder fra ditt Media Center", "pictureUpload.jsp");
		Service scheduleRecording = new Service("scheduleRecording", "Programmr TV-opptak", "scheduleRecording.jsp");
		
		/* Creates the user "andreas". */
		User user1 = new User("andreas");
		user1.addService(pic);
		user1.addService(games);
		user1.addService(services[0]);
		user1.addService(services[1]);
		user1.addRemoteService(downloadPictures);
		user1.addRemoteService(uploadPictures);
		user1.addRemoteService(scheduleRecording);
		database.put(user1.getUsername(), user1);
		
		/* Creates the user "oystein". */
		User user2 = new User("oystein");
		user2.addService(pic);
		user2.addService(games);
		user2.addService(services[0]);
		user2.addService(services[2]);
		user2.addService(services[3]);
		user2.addRemoteService(downloadPictures);
		user2.addRemoteService(uploadPictures);
		user2.addRemoteService(scheduleRecording);
		database.put(user2.getUsername(), user2);
		
		/* Creates the user "oyvind" */
		User user3 = new User("oyvind");
		user3.addService(pic);
		user3.addService(games);
		user3.addService(services[0]);
		user3.addService(services[1]);
		user3.addService(services[2]);
		user3.addService(services[3]);
		user3.addRemoteService(downloadPictures);
		user3.addRemoteService(uploadPictures);
		user3.addRemoteService(scheduleRecording);
		database.put(user3.getUsername(), user3);
	}
	
	/**
	 * Gets a User object representing the user with the given username.
	 * 
	 * @param username the username of the user.
	 * @return the specified User.
	 */
	public User getUser(String username) {
		try {
			User u = database.get(username);
			return u;
		} catch (Exception e) {
			return null;
		}
	}

}
	
