package digital_home.parser;

import org.jdom.Document;
import org.jdom.Element;

import digital_home.FileTransferManager;
import digital_home.Server;
import digital_home.XMLConnection;
import digital_home.XMLVariables;

/**
 * Class for parsing file transfer requests.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class DownloadParser extends XMLServiceParser {
	
	private FileTransferManager ftMan;
	
	/**
	 * Creates a new File Transfer Parser.
	 * 
	 * @param server The server this parser belongs to.
	 */
	public DownloadParser(Server server) {
		super(XMLVariables.FILE_DOWNLOAD_ID, server);
		
		ftMan = server.getFileTransferManager();
	}

	/**
	 * Receives the file transfer XML element and requests a 
	 * download at the File Transfer Manager. 
	 * 
	 * @return the response to the RMI caller, null if no such call has been made.
	 */
	public Document receiveXML(Element body, XMLConnection con) {
		String username = con.getUsername();
		String status = body.getChildText(XMLVariables.STATUS);
		String fileName = body.getChildText(XMLVariables.FILE_NAME);
		String fileType = body.getChildText(XMLVariables.FILE_TYPE);
		Document response = null;
		
		if(status != null){
			if (XMLVariables.STATUS_FILEINFO_OK.equals(status)){
				server.log("FileTransferParser: File info ok received.");
				ftMan.fileInfoReceived(username);
			} else if (XMLVariables.STATUS_FILE_OK.equals(status)){
				server.log("FileTransferParser: File ok received.");
				ftMan.fileOkReceived(username);
				
				if ("DigitalHomeClient".equals(fileName) && "dll".equals(fileType)) {
					String updateStatus = body.getChild(XMLVariables.STATUS).getAttributeValue(XMLVariables.STATUS_UPDATE);
					
					if ("ok".equals(updateStatus)) {
						con.setClientUpdated(true);
					}
				} 
			} else if (XMLVariables.STATUS_FILE_FAILED.equals(status)) {
				server.log("FileTransferParser: File failed received.");
				
				/* Here we are just informing the download connection to remote the element from the queue
				 * and start transfering the next element. Some sort of retransmission of the failed element 
				 * could be implemented here. */
				ftMan.fileOkReceived(username);
			}		
		} else {			
			Element rootElement = new Element(XMLVariables.RMI_ROOT);
			Element bodyElement = new Element(XMLVariables.RMI_BODY);
			Element statusElement = new Element(XMLVariables.RMI_STATUS);
			
			statusElement.setText(XMLVariables.RMI_STATUS_SUCCESS);
			bodyElement.addContent(statusElement);
			rootElement.addContent(bodyElement);
			response = new Document(rootElement);
			
			ftMan.receiveDownloadRequest(username, body);
		}
		
		return response;
	}

}
