package digital_home.parser;

import org.jdom.Document;
import org.jdom.Element;

import digital_home.*;
import digital_home.service.*;

/**
 * Class for parsing requests for file lists.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class FileListParser extends XMLServiceParser {

	private FileListManager fileListMan;
	
	/**
	 * Creates a new file list parser.
	 * 
	 * @param server the server this parser belongs to.
	 */
	public FileListParser(Server server) {
		super("FileList", server);
		
		fileListMan = new FileListManager();
	}
	
	/**
	 * Receives an XML document for parsing.
	 * 
	 * @return always null.
	 */
	public Document receiveXML(Element body, XMLConnection con) {
		
		Element element = body.getChild("fileType");
		
		if (element != null) {
			return fileListMan.startFileListRequest(body, con);
		} else {
			element = body.getChild("fileList");
			
			if (element == null) {
				return null;
			}
			
			fileListMan.responseReceived(body, con.getUsername());
			return null;
		}
	}

}
