package digital_home.parser;

import org.jdom.Document;
import org.jdom.Element;

import digital_home.*;

/**
 * Class for parsing requests to schedule TV recordings.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class ScheduleTvRecordingParser extends XMLServiceParser {

	/**
	 * Creates a new TV schedule recording parser.
	 * 
	 * @param server the server this parser belongs to.
	 */
	public ScheduleTvRecordingParser(Server server) {
		super(XMLVariables.SCHEDULE_RECORDING_ID, server);
	}

	/**
	 * Receives an XML document for parsing.
	 * 
	 * @return the response to the RMI caller.
	 */
	public Document receiveXML(Element body, XMLConnection con) {
		server.log("ScheduleParser: mottok doc ");
		
		/* Creating response */
		Element responseRoot = new Element(XMLVariables.RMI_ROOT);
		Element responseBody = new Element(XMLVariables.RMI_BODY);
		Element responseStatus = new Element(XMLVariables.RMI_STATUS);
		Document response = new Document(responseRoot);
		
		responseBody.addContent(responseStatus);
		responseRoot.addContent(responseBody);
		
		/* Parsing message */
		String program = body.getChildText(XMLVariables.SCHEDULE_RECORDING_PROGRAM);
		String service = body.getChildText(XMLVariables.SCHEDULE_RECORDING_SERVICE);
		String isRecurring = body.getChildText(XMLVariables.SCHEDULE_RECORDING_RECURRING);
		
		if (program != null && service != null && 
		    ("true".equals(isRecurring) || "false".equals(isRecurring))) {
			
			server.log("ScheduleParser: meldingsformat ok");
			
			Element serviceRoot = new Element(XMLVariables.SERVICE_ROOT);
			Document request = new Document(serviceRoot);
			
			serviceRoot.setAttribute(XMLVariables.SERVICE_ID, XMLVariables.SCHEDULE_RECORDING_ID);
			serviceRoot.addContent((Element) body.clone());
			
			responseStatus.setText(XMLVariables.RMI_STATUS_SUCCESS);
			
			con.sendXMLDoc(request);
		} else {
			server.log("ScehduleParser: feil meldingsformat");
			responseStatus.setText(XMLVariables.RMI_STATUS_FAILED);
		}
		
		return response;
	}

}
