package digital_home.parser;

import org.jdom.Document;
import org.jdom.Element;

import digital_home.Server;
import digital_home.XMLConnection;
import digital_home.XMLVariables;

/**
 * Parser for server system response messages.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class ServerSystemResponseParser extends XMLServiceParser {

	/**
	 * Creates a new server system response parser.
	 * 
	 * @param server the server this parser belongs to.
	 */
	public ServerSystemResponseParser(Server server) {
		super(XMLVariables.SERVER_SYSTEM_RESPONSE, server);
		// TODO Auto-generated constructor stub
	}

	/**
	 * Receives an XML document for parsing.
	 * 
	 * @return always null.
	 */
	public Document receiveXML(Element body, XMLConnection con) {
		Document response;
		Element root = new Element(XMLVariables.SERVER_SYSTEM_RESPONSE);
		String username = body.getAttributeValue(XMLVariables.AUTH_USERNAME);
		String version = body.getAttributeValue(XMLVariables.AUTH_VERSION);
		boolean authOk = server.getConnectionManager().autenticateConnection(username, version, con);	
		
		if (authOk) {		
			/* Create authenticate OK message to be sent to the client */
			root.setAttribute(XMLVariables.SERVER_SYSTEM_AUTH_RESPONSE, "true");	
		} else {
			/* Create authenticate failed message to be sent to the client */
			root.setAttribute(XMLVariables.SERVER_SYSTEM_AUTH_RESPONSE, "false");
		}
			
		/* Sends a response to the client with the status of the authentication */
		response = new Document(root);
		con.sendXMLDoc(response);
		
		if(authOk && server.newClientVersionExist(version)) {
			server.sendUpdatedClientSoftware(con);
		}
		
		return null;
	}
}
