package digital_home.parser;

import org.jdom.Document;
import org.jdom.Element;

import digital_home.*;

/**
 * Class for parsing file upload requests.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class UploadParser extends XMLServiceParser {

	private FileTransferManager ftMan;
	
	/**
	 * Creates a new upload parser.
	 * 
	 * @param server the server this parser belongs to.
	 */
	public UploadParser(Server server) {
		super(XMLVariables.FILE_UPLOAD_ID, server);
		
		ftMan = server.getFileTransferManager();
	}

	/**
	 * Receives an XML document for parsing.
	 * 
	 * @return he response to the RMI caller, null if no such call has been made.
	 */
	public Document receiveXML(Element body, XMLConnection con) {
		String userName = con.getUsername();
		String status = body.getChildText(XMLVariables.STATUS);
		Document response = null;
				
		if (XMLVariables.STATUS_CLOSE.equals(status)) {
			server.log("UploadParser: Received close message.");
			ftMan.closeUploadConnection(userName);
		} else if (XMLVariables.STATUS_NO_FILE.equals(status)) {
			server.log("UploadParser: The client does not have the requested file.");
			ftMan.setNoUploadFileReceived(userName, con);
		} else if (XMLVariables.STATUS_RMI.equals(status)) {
			server.log("UploadParser: Request received from RMI.");
			Element rootElement = new Element(XMLVariables.RMI_ROOT);
			Element bodyElement = new Element(XMLVariables.RMI_BODY);
			Element transferStatusElement = new Element(XMLVariables.RMI_STATUS);
			String result;
			
			body.removeChild(XMLVariables.STATUS);
			
			/* This method only returns if the file is already uploaded or when the file has
			 * been uploaded. */
			result = ftMan.receiveUploadRequest(userName, body, con);
			
			transferStatusElement.setText(result);
			bodyElement.addContent(transferStatusElement);
			rootElement.addContent(bodyElement);
			response = new Document(rootElement);
		} else {
			/* Received file info message from client, prepares to receive file */
			server.log("UploadParser: FileInfo reveiced from client.");
			String fileName = body.getChildText(XMLVariables.FILE_NAME);
			String fileType = body.getChildText(XMLVariables.FILE_TYPE);
			
			ftMan.receivedUploadFileInfo(userName, fileName, fileType, con);
		}

		return response;
	}

}
