package digital_home.parser;

import org.jdom.Document;
import org.jdom.Element;

import digital_home.Server;
import digital_home.XMLConnection;

/**
 * Interface for all XMLServiceParsers
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public abstract class XMLServiceParser {

	protected String serviceID;
	
	protected Server server;
	
	/**
	 * Constructor assigning the service a name
	 * 
	 * @param serviceID		The name of the service
	 */
	public XMLServiceParser(String serviceID, Server server) {
		this.serviceID = serviceID;
		this.server = server;
	}
	
	/**
	 * Method to get the service name
	 * 
	 * @return	The name of the service
	 */
	public String getServiceID() {
		return serviceID;
	}
	
	/**
	 * Abstract method used to by the parser to accept messages to be parsed.
	 * This is a parser's entrypoint. All parsers must implement this method. 
	 * 
	 * @param body	The XML message which is to be parsed
	 * @param con	The connection used to send XML replies to the client Media Center PC
	 * @return response to an RMI caller if any
	 */
	public abstract Document receiveXML(Element body, XMLConnection con);
}
