package digital_home.rmi;
import java.rmi.Naming;
import java.rmi.NotBoundException;

import org.jdom.Document;
import org.jdom.Element;

import digital_home.NetworkVariables;
import digital_home.XMLVariables;

/**
 * Class sending a download request from the picture service jsp.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class RMIPictureService {
	
	private String fileName;
	private String fileType;
	private String username;
	
	/**
	 * Creates a new RMIPictureService with input determing the file download.
	 * 
	 * @param fileName The name of the file the user wishes to download.
	 * @param fileType The type of file the user wishes to download.
	 * @param username The user who wishes to download a file.
	 */
	public RMIPictureService(String fileName, String fileType, String username) {
		this.fileName = fileName;
		this.fileType = fileType;
		this.username = username;
	}
	
	/**
	 * Creates and sends the download request when the thread is started.
	 */
	public boolean sendRequest() {
		System.setSecurityManager(new LiberalSecurityManager() );

		 try {
			 RMIReceiverInterface receiver = (RMIReceiverInterface) Naming.lookup(NetworkVariables.RMI_URL);
			 
			 Element root = new Element(XMLVariables.SERVICE_ROOT);
			 root.setAttribute(XMLVariables.SERVICE_USER, username);
			 root.setAttribute(XMLVariables.SERVICE_ID, XMLVariables.FILE_DOWNLOAD_ID);
			 
			 Element body = new Element(XMLVariables.SERVICE_BODY);	 
			 root.addContent(body);
			 
			 Element fileTypeElement = new Element(XMLVariables.FILE_TYPE);
			 fileTypeElement.setText(fileType);
			 Element filePathElement = new Element(XMLVariables.FILE_PATH);
			 filePathElement.setText("C:\\Tomcat\\webapps\\ROOT\\digital_home\\Images\\PictureService\\");
			 Element fileNameElement = new Element(XMLVariables.FILE_NAME);
			 fileNameElement.setText(fileName);
			 
			 body.addContent(fileTypeElement);
			 body.addContent(filePathElement);
			 body.addContent(fileNameElement);
			 
			 Document doc = new Document(root);
			 
			 Document response = receiver.receiveXML(doc);
			 
			 if(response == null){
				 return false;
			 } 

			 Element responseRoot = response.getRootElement();
			 
			 if (responseRoot == null) {
				 return false;
			 }
			 
			 Element responseBody = responseRoot.getChild(XMLVariables.RMI_BODY);
			 
			 if (responseBody == null) {
				 return false;
			 }
			 
			 String status = responseBody.getChildText(XMLVariables.RMI_STATUS);
			 
			 if (status == null || status.equals(XMLVariables.RMI_STATUS_FAILED)) {
				 return false;
			 } else {
				 return true;
			 }
			 
		 } catch (NotBoundException nbe) {
			 return false;
		 } catch (Exception e) {
			 return false;
		 }
	}
}