package digital_home.rmi;

import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;

import org.jdom.Document;

import digital_home.Server;
import digital_home.XMLConnection;

/**
 * Class which services can access through Java RMI.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class RMIReceiver extends UnicastRemoteObject implements RMIReceiverInterface {

	/* The server this RMIReceiver belongs to */
	private Server server;
	
	/**
	 * Creates a new RMIReceiver.
	 * 
	 * @param server The server this RMIReceiver belongs to.
	 * @throws RemoteException
	 */
	public RMIReceiver(Server server) throws RemoteException {
		this.server = server;
	}
	
	/**
	 * Method for sending an JDOM XML document to the server through Java RMI.
	 * 
	 * @param doc The XML document to be sent.
	 * @throws RemoteException
	 */
	public Document receiveXML(Document doc) throws RemoteException {	
		server.log("RMIReceiver: Received an XML document");
		return server.receiveXMLDoc(doc, null);		
	}
	
	/**
	 * Checks the online status of the MCE for the user with the given username.
	 * 
	 * @param username the username of the client.
	 * @return true if the MCE is online, else false.
	 * @throws RemoteException
	 */
	public boolean checkStatus(String username) throws RemoteException {
		XMLConnection con = server.getConnectionManager().getClientConnection(username);
				
		if (con == null) {
			return false;
		}
		
		return true;
	}
	
	/**
	 * Method for sending a log entry to the server.
	 * 
	 * @param text the text which is to be logged.
	 * @throws RemoteException
	 */
	public void logToServer(String text){
		server.log(text);
	}
}
