package digital_home.rmi;

import java.rmi.Remote;
import java.rmi.RemoteException;

import org.jdom.Document;

import digital_home.Server;

/**
 * Interface for the class which services can access through Java RMI.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public interface RMIReceiverInterface extends Remote {
	
	/**
	 * Method for sending an JDOM XML document to the server through Java RMI.
	 * 
	 * @param doc The XML document to be sent.
	 * @throws RemoteException
	 */
	public Document receiveXML(Document doc) throws RemoteException;
	
	/**
	 * Checks the online status of the MCE for the user with the given username.
	 * 
	 * @param username the username of the client.
	 * @return true if the MCE is online, else false.
	 * @throws RemoteException
	 */
	public boolean checkStatus(String userName) throws RemoteException;

	/**
	 * Method for sending a log entry to the server.
	 * 
	 * @param text the text which is to be logged.
	 * @throws RemoteException
	 */
	public void logToServer(String text) throws RemoteException;
}
