package digital_home.rmi;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;

import org.jdom.Document;
import org.jdom.Element;

import digital_home.*;

/**
 * Class for scheduling recordings through RMI.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class RMIScheduleRecording {
	
	private String program;
	private String service;
	private String isRecurring;
	private String userName;
	
	/**
	 * Creates a new RMIScheduleRecording object.
	 * 
	 * @param program the program which to record.
	 * @param service the channel to record from.
	 * @param isRecurring whether the recording should be recurring or not.
	 * @param userName the username of the client on which to program the recording.
	 */
	public RMIScheduleRecording(String program, String service, String isRecurring, String userName) {
		this.program = program;
		this.service = service;
		this.isRecurring = isRecurring;
		this.userName = userName;
	}
	
	/**
	 * Sends the recording request.
	 * 
	 * @return "true" if the recording request was sent to the client, else an error message.
	 */
	public String sendRequest() {
		System.setSecurityManager(new LiberalSecurityManager() );
		try {
			RMIReceiverInterface receiver = (RMIReceiverInterface) Naming.lookup(NetworkVariables.RMI_URL);
			
			Element requestRoot = new Element(XMLVariables.SERVICE_ROOT);
			Element requestBody = new Element(XMLVariables.SERVICE_BODY);
			Element programElement = new Element(XMLVariables.SCHEDULE_RECORDING_PROGRAM);
			Element serviceElement = new Element(XMLVariables.SCHEDULE_RECORDING_SERVICE);
			Element recurringElement = new Element(XMLVariables.SCHEDULE_RECORDING_RECURRING);
			Document request = new Document(requestRoot); 
			
			requestRoot.setAttribute(XMLVariables.SERVICE_ID, XMLVariables.SCHEDULE_RECORDING_ID);
			requestRoot.setAttribute(XMLVariables.SERVICE_USER, userName);
			
			programElement.setText(program);
			serviceElement.setText(service);
			recurringElement.setText(isRecurring);
			requestBody.addContent(programElement);
			requestBody.addContent(serviceElement);
			requestBody.addContent(recurringElement);
			requestRoot.addContent(requestBody);
			
			Document response = receiver.receiveXML(request);
			
			if(response == null){
				 return "Feil: Mottok inget svar fra server.";
			 } 

			 Element responseRoot = response.getRootElement();
			 
			 if (responseRoot == null) {
				 return "Feil: Mottok tomt svar fra server.";
			 }
			 
			 Element responseBody = responseRoot.getChild(XMLVariables.RMI_BODY);
			 
			 if (responseBody == null) {
				 
				 if (XMLVariables.SERVER_SYSTEM_RESPONSE.equals(responseRoot.getName())) {
					 String status = responseRoot.getAttributeValue(XMLVariables.SERVER_SYSTEM_MCE_CONNECTED);
					 
					 if (status != null) {
						 return "Feil: Ditt Media Center er ikke tilkoblet.";
					 }
					 
					 status = responseRoot.getAttributeValue(XMLVariables.STATUS);
					 
					 if (XMLVariables.STATUS_ERROR.equals(status)) {
						 return "Feil: Feil oppstod ved parsing av melding p server.";
					 }
					 
				 }
				 
				 return "Feil: Galt format p svar fra server.";
			 }
			 
			 String status = responseBody.getChildText(XMLVariables.RMI_STATUS);
			 
			 if (status == null || status.equals(XMLVariables.RMI_STATUS_FAILED)) {
				 return "Ditt Media Center kunne ikke programmere dette opptaket.";
			 } else {
				 return "true";
			 }
			
		} catch (Exception e) {
			return "Feil: Ukjent feil oppstod";
		}
		
		
	}
}
