package digital_home.rmi;

import java.rmi.Naming;
import java.rmi.NotBoundException;

import org.jdom.Document;
import org.jdom.Element;

import digital_home.NetworkVariables;
import digital_home.XMLVariables;

public class RMIUploadPictures {
	private String fileName;
	private String fileType;
	private String username;
	
	/**
	 * Creates a new RMIUploadPictures with input determing the file upload.
	 * 
	 * @param fileName The name of the file the user wishes to upload.
	 * @param fileType The type of file the user wishes to upload.
	 * @param username The user who wishes to upload a file.
	 */
	public RMIUploadPictures(String fileName, String fileType, String username) {
		this.fileName = fileName;
		this.fileType = fileType;
		this.username = username;
	}
	
	/**
	 * Creates and sends the download request when the thread is started.
	 * @return "true" if the recording request was sent to the client, else an error message.	 * 
	 */
	public String sendRequest() {
		System.setSecurityManager(new LiberalSecurityManager() );

		 try {
			 RMIReceiverInterface receiver = (RMIReceiverInterface) Naming.lookup(NetworkVariables.RMI_URL);
			 
			 Element root = new Element(XMLVariables.SERVICE_ROOT);
			 root.setAttribute(XMLVariables.SERVICE_USER, username);
			 root.setAttribute(XMLVariables.SERVICE_ID, XMLVariables.FILE_UPLOAD_ID);
			 
			 Element body = new Element(XMLVariables.SERVICE_BODY);	 
			 root.addContent(body);
			 
			 Element fileTypeElement = new Element(XMLVariables.FILE_TYPE);
			 fileTypeElement.setText(fileType);
			 Element fileNameElement = new Element(XMLVariables.FILE_NAME);
			 fileNameElement.setText(fileName);
			 Element statusElement = new Element(XMLVariables.STATUS);
			 statusElement.setText(XMLVariables.STATUS_RMI);
			 
			 body.addContent(fileTypeElement);
			 body.addContent(fileNameElement);
			 body.addContent(statusElement);
			 
			 Document doc = new Document(root);
			 
			 Document response = receiver.receiveXML(doc);
			 
			 if(response == null){
				 return "Feil: Mottok inget svar fra server.";
			 } 

			 Element responseRoot = response.getRootElement();
			 
			 if (responseRoot == null) {
				 return "Feil: Mottok tomt svar fra server.";
			 }
			 
			 Element responseBody = responseRoot.getChild(XMLVariables.RMI_BODY);
			 
			 if (responseBody == null) {
				 
				 if (XMLVariables.SERVER_SYSTEM_RESPONSE.equals(responseRoot.getName())) {
					 String status = responseRoot.getAttributeValue(XMLVariables.SERVER_SYSTEM_MCE_CONNECTED);
					 
					 if (status != null) {
						 return "Feil: Ditt Media Center er ikke tilkoblet.";
					 }
					 
					 status = responseRoot.getAttributeValue(XMLVariables.STATUS);
					 
					 if (XMLVariables.STATUS_ERROR.equals(status)) {
						 return "Feil: Feil oppstod ved parsing av melding p server.";
					 }
					 
				 }
				 
				 return "Feil: Galt format p svar fra server.";
			 }
			 
			 String status = responseBody.getChildText(XMLVariables.RMI_STATUS);
			 
			 if (status == null || status.equals(XMLVariables.RMI_STATUS_FAILED)) {
				 return "Den valgte filen var ikke tilgjengelig p ditt Media Center.";
			 } else if (XMLVariables.RMI_STATUS_QUEUED.equals(status)){
				 return "Hentingen er lagt i k og vil bli lastet opp s raskt som mulig.";
			 } else {
				 return "true";
			 }
	 
		 } catch (NotBoundException nbe) {
			 return "Feil: Fikk ikke kontaktet server.";
		 } catch (Exception e) {
			 return "Feil: En feil oppstod.";
		 }
	}
}
