package digital_home.service;

import java.util.Hashtable;

import org.jdom.Document;
import org.jdom.Element;

import digital_home.*;

/**
 * Class managing all file list requests.
 * 
 * @author Andreas W. Bjerkhaug
 * @author ystein Ellingb
 */
public class FileListManager {
	
	private Hashtable<String, FileListService> activeRequests;
	
	/**
	 * Creates a new file list manager.
	 */
	public FileListManager() {
		activeRequests = new Hashtable<String, FileListService>();
	}
	
	/**
	 * Method called when a new request for a file list has been received.
	 * This method only returns when the file list has been received at the server.
	 * 
	 * @param body the body element of the file list request.
	 * @param con the XMLConnection the request is going to be sent through.
	 * @return a response to the user once the file list has been transmitted to the server.
	 */
	public Document startFileListRequest(Element body, XMLConnection con) {
		FileListService fls = new FileListService(con.getUsername());
		
		activeRequests.put(fls.getUserName(), fls);
		
		return fls.requestFileList(body, con);
	}
	
	/**
	 * Method called when the file list has been received at the server.
	 * Wakes up the appriate thread.
	 * 
	 * @param body the body of the received message.
	 * @param username the username of the client from which the file list was received.
	 */
	public void responseReceived(Element body, String username) {
		FileListService fls = activeRequests.remove(username);
		
		if (fls != null) {
			fls.responseReceived(body);
		}
	}

}
