package digital_home.service;

import org.jdom.Document;
import org.jdom.Element;

import digital_home.*;

/**
 * Class that lets calls through RMI requesting a file list to wait for 
 * a response from the client.
 * 
 * @author Andreas W. Bjerkhaug
 *
 */
public class FileListService {
	
	private String username;
	private Document response = null;
	
	/**
	 * Creates a new file list service.
	 * 
	 * @param username the username of the client the request was sent to.
	 */
	public FileListService(String username) {
		this.username = username;	
	}
	
	/**
	 * Returns the username assosiated with this object.
	 * 
	 * @return the username assosiated with this object.
	 */
	public String getUserName() {
		return username;
	}
	
	/**
	 * Method called when response was received from the client.
	 * Wakes up the sleeping RMI thread.
	 * 
	 * @param responseBody the body of the response.
	 */
	public synchronized void responseReceived(Element responseBody) {
		Element root = new Element(XMLVariables.SERVICE_ROOT);
		Document doc = new Document(root);
		
		root.addContent((Element) responseBody.clone());
		root.setAttribute(XMLVariables.SERVICE_ID, "FileList");
		
		response = doc;
		
		notify();
	}
	
	/**
	 * Method called when the RMI thread is requesting a file list.
	 * This method only returns when the file list has been received at the server.
	 * 
	 * @param body the body of the request.
	 * @param con the XMLConnection through which to send the request.
	 * @return the response to the RMI caller.
	 */
	public synchronized Document requestFileList(Element body, XMLConnection con) {
		Element root = new Element(XMLVariables.SERVICE_ROOT);
		Document doc = new Document(root);
		
		root.addContent((Element) body.clone());
		root.setAttribute(XMLVariables.SERVICE_ID, "FileList");
		
		con.sendXMLDoc(doc);
		
		try {
			wait();
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
		
		return response;
	}
	
}
